import  { useState, useEffect } from "react";
import { TiDelete } from "react-icons/ti";
import styles from "./TodoItem.module.css";

const TodoItem = ({ item, handleToggleComplete, handleUpdate, handleDelete, error }) => {
  const [showConfirm, setShowConfirm] = useState(false);
  const [text, setText] = useState(item.text);

  
  useEffect(() => {
    const handler = setTimeout(() => {
      if (text !== item.text) {
        handleUpdate(item.id, text);
      }
    }, 1000);

    return () => {
      clearTimeout(handler);
    };
  }, [text, item.id, item.text, handleUpdate]);

  const confirmDelete = () => {
    handleDelete(item.id);
    setShowConfirm(false);
  };

  return (
    <li className={styles.list}>
      <input
        type="checkbox"
        checked={item.completed}
        onChange={() => handleToggleComplete(item.id, !item.completed)}
        className={styles.listCheckbox}
      />
      <input
        type="text"
        value={text}
        onChange={(e) => setText(e.target.value)}
        className={`${styles.todoContent} ${item.completed ? styles.todoContentCompleted : ""}`}
      />
      {error && <div className={styles.error}>{error}</div>}
      <button onClick={() => setShowConfirm(true)} className={styles.listButton}>
        <TiDelete className={styles.deletebutton} />
      </button>
      {showConfirm && (
        <div className={styles.modalOverlay}>
          <div className={styles.modal}>
            <p>Are you sure you want to delete this todo?</p>
            <div className={styles.modalButtons}>
              <button onClick={confirmDelete} className={styles.confirmButton}>OK</button>
              <button onClick={() => setShowConfirm(false)} className={styles.cancelButton}>Cancel</button>
            </div>
          </div>
        </div>
      )}
    </li>
  );
};

export default TodoItem;
