import { useEffect, useState } from "react";
import {getTodos,addTodo,deleteTodo,updateTodo} from "../../api/todo.js"; 
import TodoList from "../../component/TodoList/TodoList.jsx";
import TodoForm from "../../component/TodoForm/TodoForm.jsx";
import styles from "./Todo.module.css";

function Todo() {
  const [todos, setTodos] = useState([]);
  const [input, setInput] = useState("");
  const [error, setError] = useState("");
  const [updateErrors, setUpdateErrors] = useState({});

useEffect(() => {
    getTodos().then((res) => setTodos(res.data));
  }, []);
const handleInputChange=(e)=>{
  setInput(e.target.value);
  if(e.target.value.trim()!==""){
    setError("");
  }
};
const handleSubmit = async (e) => {
    e.preventDefault();
    if (input.trim() === "") {
      setError("Please fill this field");
       return;
    }
    setError("");
    
   
    try {
      const newTodo = { text: input, completed: false };
      const res = await addTodo(newTodo);
      setTodos([...todos, res.data]);
      setInput("");
    } catch (err) {
      console.error("Error in the adding todo:", err);
    }
  };

  const handleDelete = async (id) => {
    try {
      await deleteTodo(id);
      setTodos(todos.filter((item) => item.id !== id));
    } catch (err) {
      console.error("Error in the deleting todo:", err);
    }
  };

  const handleUpdate = async (id, updatedText) => {

    const updatedTodo = todos.find((item) => item.id === id);
    if (!updatedTodo) return;
  
    const newTodo = { ...updatedTodo, text: updatedText };
    await updateTodo(id,newTodo);
  
    setTodos(todos.map((item) =>
      item.id === id ? { ...item, text: updatedText } : item
    ));
    if (updatedText === '') {
      setUpdateErrors((prev) => ({ ...prev, [id]: "Todo cannot be empty" }));
      return;
    } 
    setUpdateErrors((prev) => ({ ...prev, [id]: null }));
  };

 const handleToggleComplete = async (id, completed) => {
    const updatedTodo = todos.find((item) => item.id === id);
    if (!updatedTodo) return;

    try {
      const newTodo = { ...updatedTodo, completed };
      await updateTodo(id, newTodo);
      setTodos(todos.map((item) =>
        item.id === id ? { ...item, completed } : item
      ));
    } catch (err) {
      console.error("Error in the toggling complete todo:", err);
    }
  };

  return (
    <div className={styles.wrapper}>
    <div className={styles.container}>
      <div className={styles.wrap}>
        <h1 className={styles.title}>
        You have {todos.length} {todos.length === 1 ? "Todo" : "Todos"}
      </h1>
      </div>
      
      {todos.length === 0 ? (
        <p className={styles.message}>No task</p>
      ) : (
        <TodoList todos={todos} handleToggleComplete={handleToggleComplete} handleUpdate={handleUpdate} handleDelete={handleDelete} updateErrors={updateErrors}/>
      )}
      <TodoForm input={input} error={error} handleInputChange={handleInputChange} handleSubmit={handleSubmit}/>
    </div>
    </div>
  );
}

export default Todo;
